instrumenttools.Piccolo
=======================

.. abjad-lineage:: abjad.tools.instrumenttools.Piccolo.Piccolo

.. autoclass:: abjad.tools.instrumenttools.Piccolo.Piccolo

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.instrumenttools.Piccolo.Piccolo.allowable_clefs
      ~abjad.tools.instrumenttools.Piccolo.Piccolo.instrument_name
      ~abjad.tools.instrumenttools.Piccolo.Piccolo.instrument_name_markup
      ~abjad.tools.instrumenttools.Piccolo.Piccolo.pitch_range
      ~abjad.tools.instrumenttools.Piccolo.Piccolo.short_instrument_name
      ~abjad.tools.instrumenttools.Piccolo.Piccolo.short_instrument_name_markup
      ~abjad.tools.instrumenttools.Piccolo.Piccolo.sounding_pitch_of_written_middle_c
      ~abjad.tools.instrumenttools.Piccolo.Piccolo.__copy__
      ~abjad.tools.instrumenttools.Piccolo.Piccolo.__eq__
      ~abjad.tools.instrumenttools.Piccolo.Piccolo.__format__
      ~abjad.tools.instrumenttools.Piccolo.Piccolo.__hash__
      ~abjad.tools.instrumenttools.Piccolo.Piccolo.__makenew__
      ~abjad.tools.instrumenttools.Piccolo.Piccolo.__ne__
      ~abjad.tools.instrumenttools.Piccolo.Piccolo.__repr__

Bases
-----

- :py:class:`instrumenttools.Instrument <abjad.tools.instrumenttools.Instrument.Instrument>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.Piccolo.Piccolo.allowable_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Piccolo.Piccolo.instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Piccolo.Piccolo.instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Piccolo.Piccolo.pitch_range
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Piccolo.Piccolo.short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Piccolo.Piccolo.short_instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Piccolo.Piccolo.sounding_pitch_of_written_middle_c
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.instrumenttools.Piccolo.Piccolo.__copy__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Piccolo.Piccolo.__eq__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Piccolo.Piccolo.__format__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Piccolo.Piccolo.__hash__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Piccolo.Piccolo.__makenew__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Piccolo.Piccolo.__ne__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Piccolo.Piccolo.__repr__
   :noindex:
